from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\x9f\xa6\x90\xf8\x84\x15\x43\x6d\x19\xdb\xbf\x53\x37\x61\xed\x12\x00\x00\x00\x00\x00\x00\x00\x00\xa8\x30\x59\xa0\xb8\xdb\xcc\x1d\x87\x26\xc2\x49\x06\x1d\xc3\x4a\x2a\xae\x32\x2f\x1a\xb0\xfa\xfc\x7d\x38\x01\x85\x2c\xe4\x17\xf9\x32\xa6\xf9\xda\xe1\x89\x4a\xb0\x4e\x55\x6f\x13\xfe\x91\xaa\x08\x42\xac\xb6\x52\xe3\x5f\x37\x7e\x98\xb8\x72\x55\xf1\xf2\xfa\x76\x97\x9a\x28\x75\xe7\xcd\x83\x5b\x4c\x67\x9a\x98\xf9\xd4\xad\x28\xa0\xc2\x5c\xe8\xc6\xae\x1d\xc1\x95\x40\x6b\xe6\xa4\x02\xea\x68\x65\xc4\xf0\x0f\xb2\x07\xe0\x48\x3a\x28\x7a\x15\x0c\x56\x1d\xe1\xb7\xef\x31\x24\x76\x62\x00\x47\x65\xd9\x61\x94\x88\xb3\x17\xfe\xc6\x1e\x20\x6e\x91\x74\x63\x56\x9f\x98\x43\xf7\xc9\xc6\x8a\x0f\xf0\xcd\x8c\xad\x8c\xb5\xb7\xda\x02\x54\x27\xbb\x38\xe1\x6d\x0d\x1c\x34\xb5\xa4\xc8\xc3\x3b\x8f\x4d\xf0\x3b\x18\x9c\xa8\x28\x7a\xb9\xb8\x95\xbf\x0b\xfd\x4b\x85\xa8\x48\xcf\x08\x1a\x3e\xc2\x7a\x7f\xf3\xe0\xab\xa5\x59\x66\x8f\xb9\xde\x80\x3b\xc3\xcc\x7f\x67\x1a\xf3\x27\x29\x4b\xb8\xa8\xaa\x88\x36\x90\x6d\xca\xb7\xcf\xf5\xdc\x2b\x99\x7b\x35\x1e\xfa\x88\xd1\x2b\xd1\x06\x77\x9f\xe4\x04\x89\x62\x94\x3b\x44\xbf\x4d\xc8\x10\x6d\x78\x5c\x9b\x93\x3e\x50\x34\x00\x91\x8e\xc3\xa6\x34\x92\x33\x17\xae\x92\x4d\x27\xfc\xb6\xba\x0d\x32\x78\xc0\xc3\xff\xfb\x50\x35\x07\x8d\x8b\x50\x7e\xcb\x95\x44\x6e\x72\x6d\x07\x18\xd9\x6a\x19\xcd\xc4\xf6\x6c\x3b\xa6\x68\x23\xb3\x25\xcc\x61\x81\x71\xf5\xb5\xeb\xe4\x9a\xbd\x94\xc5\xab\x93\x86\x5c\xce\xad\xb0\x23\xa8\x1f\x4f\xb6\x90\x1c\xa6\x2e\xae\x94\xdc\x63\xa8\x54\xad\x9a\xb1\xe9\xbc\x26\x38\xd0\x1a\xa4\x93\xf4\xac\xd4\xf5\xaa\x10\x06\x51\x81\x25\xc9\x33\x15\x11\xaf\xb8\xd0\xd1\xd8\xc2\x5e\x1a\xa1\xdb\xfe\x55\x8c\x83\x9e\x22\x00\xc1\x5b\x17\xff\x6a\x00\x94\x2b\x96\xd4\xdf\x94\xdc\x04\x72\xa6\xf6\xc2\x29\x63\xea\xe4\x20\xc7\x1d\xab\x5c\x3b\xbe\xef\x4d\x1c\x8e\x48\xef\xdd\x17\xa7\xca\xff\xf2\x7a\xbb\xc7\x2a\x8b\xd3\x29\xb7\x2b\xac\x93\x3e\x2e\x88\xc7\xfc\xb8\xbe\x98\x94\xb0\x24\xfe\x52\x22\xe7\x40\xb5\x53\x12\x1a\x21\x7a\x5d\xdc\x99\xcd\x3d\x23\x31\x29\x8d\x56\xa9\xd6\x31\x7a\x54\xc0\x78\xd8\xd4\x84\xad\x83\x5c\xe4\x26\xf7\xcf\xc3\xd8\x03\xd9\x84\x24\x7f\x8f\x3e\xb4\x97\xce\x39\xab\xab\xb5\x78\xef\x19\xf0\xea\x6a\x7a\xef\x36\x69\x10\xcd\x1c\x2b\x4c\x1e\xf0\xef\xa6\x1a\x04\xc7\x6b\x2d\x10\xb2\xe8\x1b\x0a\x57\x71\xfa\x41\x22\x92\x41\x71\x08\x67\x73\x23\x94\xa9\xd8\x5c\xfe\x4f\xbe\xfe\x78\x00\x59\xe4\x4b\xe9\x3a\x01\x95\xb0\x77\x07\x5d\xfb\xe8\x50\xd5\x44\xb2\x31\xb8\xad\x64\xe4\x56\x39\x63\xaf\x11\x76\x2e\x10\x5b\xce\x22\xb2\x38\x3b\x57\x09\x6c\xec\x9f\x3e\xcf\xcd\x6c\xaa\x1e\xce\xde\xd4\xc2\x70\x8b\xfa\xeb\x72\x68\xf5\x5d\x06\x7d\xfb\x1c\xc5\x06\x41\xad\xce\x02\xd6\x73\xea\x5e\x2d\x0d\x34\xc5\x35\xa8\xd6\x09\x8b\x98\xa6\xf1\x36\x8a\x9d\x3f\x04\xbe\xd0\x60\x25\x1d\xfd\xe9\x35\xd9\x2e\x67\xb7\x38\x02\x6d\x4c\xd8\x63\xdd\x2b\x00\x00\x65\x9b\x8d\x01\x59\x68\xf4\xfe\x30\xcb\xcf\x8a\x55\x4e\x5b\x82\x44\xb8\xfe\xc1\x00\xde\x1c\xaa\x4a\x03\x57\xf7\x4c\x5b\xc1\xd5\xd3\x5d\x81\xca\x1e\x2e\x0a\x9d\xde\x82\x5d\xff\x83\xb8\xbe\xb6\xf6\x25\x8a\xea\x79\x8a\x3f\x0b\xf5\xd2\x5a\x3e\xbd\x49\xd5\x6f\x96\xa5\xe1\xd2\xa3\x11\x00\x60\x16\xc4\xcd\xeb\x8a\x32\xdf\xe3\x7b\x98\xd0\xbe\xf7\xa9\xa7\x46\xab\x3b\x95\x9b\x0f\x38\xc0\xc3\xa4\x78\x81\x5d\xe7\x84\x7d\x10\x4c\x93\xad\x90\x7e\x63\xbe\xb0\x1e\x01\x5d\xbc\xe2\xd3\x3f\x54\xee\x23\xef\x63\x6f\x3f\xb1\x39\xc5\xc1\x55\x88\xb1\x8b\xad\x46\xb2\xda\x79\x21\xa5\x27\x8e\x12\x92\x81\xc9\xaa\xc3\x58\xb0\x0a\x67\xea\x3d\xcd\x1e\xea\x91\xc3\xa1\xfb\x22\x83\xef\x92\x1f\x5d\xa7\x47\x77\x4d\x41\x89\xa7\x79\xff\xd9\xfc\x6e\x62\x88\xe9\x05\x2b\x1f\xa3\xcd\x27\x98\xde\x38\x7c\x1d\x54\xa5\xf2\xe1\x0e\xfd\x36\x7b\xba\xc8\x28\x4d\xae\xe2\x00\x77\xa1\x82\xf1\x55\x5a\xf7\x16\x86\xe9\x33\xfa\x96\x40\xb0\x6b\x38\xfd\x69\x82\x4b\x01\xa0\x8a\xe6\x69\x25\x34\x29\x7b\x7e\xae\x99\xca\xc4\x1d\x1a\xe6\x5d\xcb\x62\xb7\xb1\x02\x93\x04\x98\x7f\xda\xe4\x73\x0c\x69\x19\x7d\xc3\x2a\xfa\xc3\x18\xf8\x40\x42\x98\x2e\x40\x4c\x32\x1e\x34\x24\x5b\x61\x62\x64\x6e\xcc\x1c\x1d\xd1\xea\x49\x45\xe9\xfc\x4f\x76\xbf\xd1\x10\xd4\x88\xac\x65\x2b\xa3\xb0\x5b\xbf\xd2\x9a\xc4\xcf\xde\xaf\xdf\xa5\xdb\x14\x85\x81\x2b\x08\xe8\x70\xd6\x46\xfe\xf1\x09\xb8\x18\xe0\x16\x09\xc0\xc2\xe6\xfe\x03\xa2\xc4\x0d\x79\x13\xaf\xf4\x82\x4e\xb3\x06\x04\xb0\xe6\x30\xa1\xb1\xd9\x95\x8e\x7e\x91\xbb\x40\x2c\xf3\xf2\x3c\x8f\x72\xc4\x6a\x43\x61\x4d\x93\xe0\x6c\x2d\xdf\x81\xfd\xea\x09\xce\x81\xff\x45\x1e\x12\xf6\x57\x1a\x75\x92\x51\x7e\x15\xca\xf1\x9e\xc9\x5d\x4e\x47\xdd\xf6\x17\xbf\xb4\x05\xf1\xb0\x47\xf9\xd2\x0a\x87\x0b\xd1\x44\xb2\x1f\x3a\x1b\x57\x7b\xcd\x27\xa9\xc2\xeb\x41\x84\x0a\x20\xee\xec\x00\xb8\xd7\x8e\x3b\x95\xd6\xb8\x26\x6c\x4b\x41\xe5\x49\x83\x1a\xeb\xbf\xba\x14\xc1\x43\x20\x7f\x02\xad\x46\x4c\x32\x5f\x1b\x8e\x37\xc4\x17\xe8\xab\x06\xe5\xb1\xcd\x3c\x92\x83\x62\x5d\x03\xae\xcb\xee\x10\x10\xf7\xb4\x98\xe3\x60\x0c\x28\x54\x0f\x99\xc9\x0a\xe6\x0f\x7d\x30\xea\xa6\x20\xd8\xc9\xca\x1a\x52\x05\x15\x6e\xda\xf5\x9a\x7a\x87\xae\xeb\x0c\x63\xa1\x4f\x45\xba\x58\xf7\x87\xbb\x79\x68\xe7\x46\x65\x4c\xb8\x6d\x41\xb1\xe2\xcc\x41\x1c\xa2\x05\x3f\x49\xa3\x54\xee\xd6\xe6\x03\x3d\x3d\x87\x66\x9c\x81\x82\x63\x69\xc2\xbd\x42\x08\x11\x20\xee\x25\xcf\x56\xe4\xd5\xe5\x6e\x8f\x0b\x1e\x50\xaf\x55\x40\xe3\x3a\xc7\xe5\x67\xa0\x8d\x09\xe1\x09\x4b\x45\xb1\x08\xf9\x91\xcb\x62\x6d\xb0\xe6\xbb\x71\x9a\x5f\xc1\xc8\x98\x99\x84\xca\x5f\x16\xcd\x68\x6c\x01\x03\xc5\xd8\xd3\xd2\xb6\x75\x8b\xb6\x84\x64\xbc\x76\x3c\xcb\x0b\x6a\x2e\xfb\x2d\x9e\x1f\x97\x7d\x13\xbf\xcf\xb4\x81\x53\xc1\x2e\x84\x34\xcf\x3b\x2e\x39\x1c\xd4\x22\xb6\x79\xa5\xdc\xfd\x2f\xf6\x14\xcf\xd2\xe4\x3e\x21\x76\xe0\x91\x5b\x7f\xb0\x6a\xef\xbe\xb0\xc0\x18\x42\x34\x72\xea\xff\xd3\x99\x00\xdd\x3b\x67\x01\xe8\x7e\xa5\xff\xd4\x1e\x04\xeb\x45\xaa\x8b\x97\x17\xdc\xa5\xc4\x91\xbf\x43\x94\xd0\xcb\x7c\x9f\x39\x02\x7d\xb3\x14\x43\x84\xb1\xa4\x95\x1b\x4f\x57\x38\x3b\x2b\xaa\xc3\xa3\x34\xc9\xd2\x41\x6a\xe7\x11\x3e\xd6\xea\x9f\xab\x8e\x8d\x39\xbe\x10\xc6\x1e\xec\x4a\xdd\xd7\x3a\x44\xc1\xc8\x33\xfe\xf7\xbc\x6f\xf9\x97\x04\x66\x7b\x83\x27\xc4\xfb\xa6\x96\xb2\x3e\xdc\x4d\x58\x53\x97\xb7\xe6\xb1\xb6\x53\x57\x7e\x21\x45\x2d\xfc\x8a\x65\xa6\x3e\x55\x2c\xf0\x12\x6f\x45\x71\xd0\xf7\x87\x74\xbf\x7e\xc8\x68\x79\xe8\x1d\x6c\xf6\xd8\x2f\x22\x14\xba\x5b\x23\xef\x93\xcd\xe0\x98\xbf\x5c\xa7\xb1\x32\x7d\x08\x6f\x4f\x25\x11\xa1\xf8\x11\xf0\x6f\x45\x3d\x0b\x73\x92\x4a\x63\xcf\xac\xbd\xdf\x21\x6b\x92\x8a\x30\x38\x23\xd0\x4b\x7c\x5c\x14\x91\x8d\x78\x93\xef\x30\xf4\xb1\xfd\xa0\x5c\x85\xee\x33\xe2\x90\xca\x23\xd6\x4b\xa6\xfb\xa1\x74\xa6\xbd\xdd\xaf\xda\x4e\x54\x16\xcd\x94\x71\x6a\x3a\xab\x4a\x8c\xfe\x31\xbc\xb3\x7d\x22\xcd\xcc\xc1\x3c\x07\xfb\xdf\x4e\x28\x15\x38\xb6\x45\x39\xa6\xf8\x2a\x6a\x02\x75\x18\xde\x74\x41\xf9\x1e\x66\x0a\x35\x06\xce\x68\x93\x5d\x90\x69\xa1\xc1\xd2\xa1\x2f\x0a\x24\x4a\xa9\x3d\xa3\x67\x22\x0c\x89\x27\x0e\xfa\xce\xfc\x57\xe0\x06\xcd\x72\xca\x55\x79\x58\xcf\x77\xa0\x3d\xcb\x86\xb4\x15\xf2\xdd\xcb\x93\xdd\x40\x41\x40\xd4\x29\xd9\x09\x30\xdd\xb5\x39\x5b\x1a\x46\x6e\x20\x13\xb0\x0a\x4d\xc5\x4b\xec\x18\xe8\x72\x0b\xdc\x8f\x32\x13\x6f\x37\x4d\xd3\xec\xc3\x21\x0f\xfc\xa2\x45\x5c\x97\x13\x2f\x8f\x75\x21\x07\x07\x79\x09\x91\xaf\x43\x08\xb7\x5c\xce\x0c\x23\x85\x3e\x62\x04\x4b\xab\xcf\x02\x4b\xee\x79\x53\x67\xcc\xc1\x06\x80\x33\xe2\x4c\x84\x2f\xb1\x56\x01\x93\x7a\xac\x79\xc3\x9b\xa3\x3e\x8c\x3f\x8a\x95\x7b\x2d\x1c\x92\x41\x17\x84\xcd\x31\x2f\x40\x09\xf1\xf0\x7e\x37\xc2\x08\xc1\x9c\xc9\x6e\x5c\xb8\x44\x16\x4b\xbe\x60\x07\x8e\xe6\xcb\x65\x0b\x73\x8c\xcf\xd6\xca\x8c\xbe\x51\x61\x7b\x71\x0a\x28\x7e\x6c\xb4\xbb\x6a\xc6\x58\x24\xbd\x93\x65\xe9\xfd\x6f\x35\x8e\x5e\xd8\x4b\x74\x50\x4b\x9f\xda\x07\x03\xdd\xa2\x24\xa9\xa2\x15\xc4\x41\x03\x23\x37\x18\x7b\xa8\xdc\x68\x7e\x18\xd4\x6e\xe0\xaa\xf8\xa7\x17\xb4\xa9\x91\x9e\x2d\xf5\x27\x72\xa4\xfc\x20\x98\x20\xb6\xb1\x30\x30\x43\x90\x8d\xff\x64\x3a\x20\xca\x6e\x4c\xc7\x0e\x6a\x76\xc5\x83\xc0\xcf\xe9\x5c\x6a\x65\xfe\x85\x78\x6e\xf0\x36\xa3\x54\xa9\xfc\xa1\x3b\xf9\x01\x03\xaf\x07\xda\x8b\x38\xdc\x42\x27\x9b\x95\xf9\x6c\xe5\xfa\x36\xf3\x88\x67\x4a\xfa\x8e\x5c\x10\x67\x01\x9c\x69\x66\x2a\xdf\x10\x8d\x15\x3b\x62\x1b\xdc\xec\x12\x23\xfa\x76\x40\x00\x0e\xf2\x2d\xf2\xd0\x6d\x8c\xe3\x62\xbb\x57\xca\x27\x64\x49\x0e\xc2\x3c\x32\xe5\x0a\x49\x2d\xcd\xce\xd5\xe9\xea\xdb\xed\x97\xe7\x49\x0b\x81\x1b\x2f\x84\x13\x7c\xd8\xfb\xc3\xbd\x62\x91\xe7\xdd\x5f\xd0\xf7\xc0\x8f\xa9\x36\x25\xec\x63\x0a\x66\x0f\x17\x81\x84\xc4\xa8\x3a\x73\x0d\x6b\x42\xb3\x1d\x72\xc9\xe1\xa4\x47\xfa\x74\x3c\x8a\x0a\xe9\xea\x08\x0f\x6b\x19\x1e\x3a\x5b\xff\x90\xab\x4b\x2a\x55\x49\x2c\x3a\x3d\x21\x40\x14\xff\xff\xa0\xa8\x98\xf8\x8a\xfe\x2a\x5c\xc5\x26\xbe\xe8\xf5\xb7\x3e\xf0\x3a\xb5\x42\x5a\x70\x62\x7c\x86\x60\x32\x22\xd6\x92\x7a\x30\xdc\x36\x0a\x91\xb2\x8b\x7d\xa0\x62\x55\x76\x78\x68\x35\xce\xfe\xfe\xa9\x3b\x96\xe5\xa7\xd0\x96\x03\x7f\xb0\x48\xcb\x08\xca\x2c\x42\x01\xb1\x09\x08\xca\xec\xc9\xbe\xcd\x0d\xaa\x05\x21\x23\x9d\xd5\x92\x96\xe3\xc4\x08\x24\xf2\x4f\x20\xc2\x27\x30\x92\x31\x2b\x1f\xa6\x23\xd8\xc6\xf4\x54\xe6\x5a\xa3\xe5\xda\x5c\xca\xa1\x3f', 2)

# cleanup
del pyarmor_runtime

